var c $c$ 
    k $k$ 
    a $a$ 
    h $h$ 
    d $d$ 
    y $y$ 
    invest $i$  
    tb $tb$ 
    mu_c ${MU_C}$ 
    tb_y ${\frac{TB}{Y}}$ 
    g_y ${\Delta Y}$
    g_c ${\Delta C}$
    g_invest ${\Delta I}$
    g ${g}$
    r ${r}$
    mu ${\mu}$
    nu ${\nu}$
     s ${s}$
    
; 

predetermined_variables k d;

%Define parameters
parameters beta ${\beta}$ 
        gamma ${\gamma}$ 
        delta ${\delta}$
        alpha ${\alpha}$
        psi  ${\psi}$
        omega ${\omega}$
        theta ${\theta}$
        phi ${\phi}$
        dbar ${\bar d}$
        gbar ${\bar g}$
        rho_a ${\rho_a}$
        rho_g ${\rho_g}$
        rho_nu ${\rho_\nu}$
        rho_mu ${\rho_\mu}$
        rho_s ${\rho_s}$
        s_share ${sshare}$
        S ${S}$
        ybar
        d_share
        
   
;

varexo  eps_a ${\varepsilon_a}$
        eps_g ${\varepsilon_g}$ 
        eps_nu ${\varepsilon_\nu}$
        eps_mu ${\varepsilon_\mu}$
        eps_s ${\varepsilon_s}$
    
;

        


gbar =    1.0048;
rho_g =   0.5;
rho_a =   0.5;
phi   =   5;

            
%parameters only used for Financial frictions model, irrelevant for RBC where volatilities are 0        
rho_nu =    0.5;
rho_s  = 0.5;
rho_mu = 0.5;

%From Table 2, except for psi, which is estimated for Financial Frictions model

gamma = 2; %intertemporal elasticity of substitution
delta = 0.013; %Depreciation rate
alpha = 0.29; %Capital elasticity of the production function
omega = 1.6; %exponent of labor in utility function
theta = 1.4*omega;
beta = 0.99;%0.98;%discount factor
d_share = -0.66;


psi = 3; %parameter governing the debt elasticity of the interest rate. 
s_share = 0.21; %Share of public spending in GDP

        
model;
#RSTAR = 1/beta * gbar^gamma; %World interest rate
%1. Interest Rate
r = RSTAR + psi*(exp((log(d(+1))/ybar)-(dbar/ybar)) - 1)+exp(mu-1)-1;

%2. Marginal utility of consumption
mu_c = nu * (c - theta/omega*h^omega)^(-gamma);

%3. Resource constraint 


    y= log(tb) + c + s + invest + phi/2 * (k(+1)/k*g -gbar)^2;


%4. Trade balance
log(tb)= log(d) - log(d(+1))*g/r;

%5. Definition output
y= a*k^alpha*(g*h)^(1-alpha);

%6. Definition investment
invest= k(+1)*g - (1-delta) *k;

%7. Euler equation
mu_c= beta/g^gamma*r*mu_c(+1);

%8. First order condition labor
theta*h^(omega-1)=(1-alpha)*a*g^(1-alpha)*(k/h)^alpha;

%9. First order condition investment
mu_c*(1+phi*(k(+1)/k*g-gbar))= beta/g^gamma*mu_c(+1)*(1-delta+alpha*a(+1)*(g(+1)*h(+1)/k(+1))^(1-alpha) +phi*k(+2)/k(+1)*g(+1)*(k(+2)/k(+1)*g(+1)-gbar) - phi/2*(k(+2)/k(+1)*g(+1)-gbar)^2);

%10. Definition trade-balance to output ratio
log(tb_y) = log(tb)/y; 

%11. Output growth
g_y= y/y(-1)*g(-1);

%12. Consumption growth
g_c = c/c(-1)*g(-1);

%13. Investment growth
g_invest = invest/invest(-1)*g(-1);

%14. LOM temporary TFP
log(a)=rho_a * log(a(-1))+eps_a; 

%15. LOM permanent TFP Growth
log(g/gbar)=rho_g*log(g(-1)/gbar)+eps_g; 

%16. Preference shock
log(nu) =rho_nu * log(nu(-1))+eps_nu;

%17. exogenous stochastic country premium shock
log(mu)= rho_mu * log(mu(-1))+eps_mu;
    

%18. Exogenous spending shock
log(s/S)= rho_s * log(s(-1)/S) + eps_s;


end;

steady_state_model;
r=1/beta*gbar^gamma; %World interest rate
k_over_gh =((gbar^gamma/beta-1+delta)/alpha)^(1/(alpha-1)); %k/(g*h)
h=((1-alpha)*gbar*k_over_gh^alpha/theta)^(1/(omega-1)); %hours
k=k_over_gh*gbar*h; %capital
invest=(gbar-1+delta)*k; %investment
y =k^alpha*(h*gbar)^(1-alpha); %output
ybar=y;
dbar=ybar*d_share;
d=dbar;%foreign debt
    s=y*s_share;
    S = s;

c =(gbar/r-1)*d +y-s-invest; %Consumption
tb = y - c - s - invest; %Trade balance
tb_y = tb /y;
mu_c = (c - theta/omega*h^omega)^(-gamma); %marginal utility of wealth
a = 1; %productivity shock 
g = gbar; %Growth rate of nonstationary productivity shock
g_c = g;
g_invest = g;
g_y= g;
nu = 1;
mu = 1;
d=exp(d);
tb=exp(tb);
tb_y=exp(tb_y);
end;

shocks;

var eps_a; stderr 0.1;
var eps_g; stderr 0.1;
var eps_nu; stderr  0.1;
var eps_s; stderr   0.1;
var eps_mu; stderr  0.1;

end;

resid(1);

steady;
check;

stoch_simul(loglinear,order=1,irf=0)g_y g_c g_invest tb_y;

varobs g_y g_invest g_c tb_y;
        
estimated_params;


rho_g,0.7907, , ,beta_pdf,0.5,0.2;
rho_a,0.9604, , ,beta_pdf,0.5,0.2;
rho_nu,0.8639, , ,beta_pdf,0.5,0.2;
rho_s,0.9918, , ,beta_pdf,0.5,0.2;
rho_mu,0.8371, , ,beta_pdf,0.5,0.2;
stderr eps_g,0.0122, , ,inv_gamma_pdf,0.1,inf;
stderr eps_a,0.0118, , ,inv_gamma_pdf,0.1,inf;
stderr eps_nu,0.0518, , ,inv_gamma_pdf,0.1,inf; 
stderr eps_s,0.0262, , ,inv_gamma_pdf,0.1,inf;
stderr eps_mu,0.0241, , ,inv_gamma_pdf,0.1,inf;
   
phi,2.4528, , ,gamma_pdf,4,2;
psi,10.1263, , ,gamma_pdf,5,2;

stderr g_y,0.003, , ,uniform_pdf, (0.0001+0.003)/2,sqrt(12)^(-1)*(0.003-0.0001), 0.0001, 0.003;
stderr g_c,0.0016, , ,uniform_pdf, (0.0001+0.002)/2,sqrt(12)^(-1)*(0.002-0.0001), 0.0001, 0.002;
stderr g_invest,0.0120, , ,uniform_pdf, (0.0001+0.012)/2,sqrt(12)^(-1)*(0.012-0.0001), 0.0001, 0.012;
stderr tb_y,0.0037, , ,uniform_pdf, (0.0001+0.004)/2,sqrt(12)^(-1)*(0.004-0.0001), 0.0001, 0.004;

end;
    

estimation(datafile=dataycitb,
        xls_range=B1:E222,
        logdata,
        mode_compute=6,
        prior_trunc=0,
        moments_varendo,
        mh_nblocks=2,
        mh_drop=0.55,
        mh_replic=300000,
        graph_format=(pdf,fig),
        bayesian_irf,
        mode_check);
identification;
Shock_decomposition y g_y;


